[CCCL] 瘦身 + 补全: 移除 cudax/python/libcudacxx-tests 冗余文件, 新增 c2h 测试助手 + cmake 构建系统 + 8 个 CUDA thrust examples
变更摘要:
- 删除: cudax/ (783 files, 7.2M) — 实验性组件,竞赛不需要
- 删除: python/ (226 files, 2.0M) — Python 绑定,竞赛不需要
- 删除: libcudacxx/{test,benchmarks,codegen,cmake,share} (4432 files, 31M)
保留: libcudacxx/include/ (1463 headers, cuda::std 编译依赖)
- 新增: c2h/ (27 files) — CUB Catch2 测试辅助头文件,编译 243 个测试必需
- 新增: cmake/ (29 files) — CCCL 原生 CMake 构建系统
- 新增: thrust/examples/cuda/ (7 files) + cpp_integration/ (1 file)
async_reduce, custom_temporary_allocation, explicit_cuda_stream,
global_device_vector, range_view, unwrap_pointer, wrap_pointer, device
结果: cccl_upstream 从 74M→35M (瘦身 53%), 核心内容 100% 保留:
27/27 tuning headers, 78 benchmarks, 243 tests,
60 thrust examples, 18 CUB examples, 全部编译头文件
This commit is contained in:
@@ -1,117 +0,0 @@
|
||||
//===----------------------------------------------------------------------===//
|
||||
//
|
||||
// Part of CUDASTF in CUDA C++ Core Libraries,
|
||||
// under the Apache License v2.0 with LLVM Exceptions.
|
||||
// See https://llvm.org/LICENSE.txt for license information.
|
||||
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
|
||||
// SPDX-FileCopyrightText: Copyright (c) 2022-2024 NVIDIA CORPORATION & AFFILIATES.
|
||||
//
|
||||
//===----------------------------------------------------------------------===//
|
||||
|
||||
/**
|
||||
* @file
|
||||
* @brief Generate a library call from nested CUDA graphs generated using algorithms
|
||||
*/
|
||||
|
||||
#include <cuda/experimental/stf.cuh>
|
||||
|
||||
using namespace cuda::experimental::stf;
|
||||
|
||||
// Some fake library doing MATH
|
||||
void libMATH(graph_ctx ctx, logical_data<slice<double>> x, logical_data<slice<double>> y)
|
||||
{
|
||||
// We only want to have kernels with 4 CTAs to stress the system
|
||||
auto spec = par<4>(par<128>());
|
||||
ctx.launch(spec, exec_place::current_device(), x.read(), y.write()).set_symbol("MATH1")->*
|
||||
[] __device__(auto t, auto x, auto y) {
|
||||
for (auto i : t.apply_partition(shape(x)))
|
||||
{
|
||||
y(i) = cos(cos(x(i)));
|
||||
}
|
||||
};
|
||||
|
||||
ctx.launch(spec, exec_place::current_device(), x.write(), y.read()).set_symbol("MATH2")->*
|
||||
[] __device__(auto t, auto x, auto y) {
|
||||
for (auto i : t.apply_partition(shape(x)))
|
||||
{
|
||||
x(i) = sin(sin(y(i)));
|
||||
};
|
||||
};
|
||||
}
|
||||
|
||||
template <typename context_t>
|
||||
void libMATH_AS_GRAPH(context_t& ctx, logical_data<slice<double>> x, logical_data<slice<double>> y)
|
||||
{
|
||||
static algorithm alg;
|
||||
alg.run_as_task(libMATH, ctx, x.rw(), y.write());
|
||||
}
|
||||
|
||||
// Some fake lib doing a SWAP
|
||||
template <typename context_t>
|
||||
void libSWAP(context_t& ctx, logical_data<slice<double>> x, logical_data<slice<double>> y)
|
||||
{
|
||||
// We only want to have kernels with 4 CTAs to stress the system
|
||||
auto spec = par<4>(par<128>());
|
||||
ctx.launch(spec, exec_place::current_device(), x.rw(), y.rw()).set_symbol("SWAP")->*
|
||||
[] __device__(auto t, auto x, auto y) {
|
||||
for (auto i : t.apply_partition(shape(x)))
|
||||
{
|
||||
auto tmp = x(i);
|
||||
x(i) = y(i);
|
||||
y(i) = tmp;
|
||||
}
|
||||
};
|
||||
}
|
||||
|
||||
template <typename context_t>
|
||||
logical_data<slice<double>> libCOPY(context_t& ctx, logical_data<slice<double>> x)
|
||||
{
|
||||
logical_data<slice<double>> res = ctx.logical_data(x.shape());
|
||||
|
||||
// We only want to have kernels with 4 CTAs to stress the system
|
||||
auto spec = par<4>(par<128>());
|
||||
ctx.launch(spec, exec_place::current_device(), x.read(), res.write()).set_symbol("SWAP")->*
|
||||
[] __device__(auto t, auto x, auto res) {
|
||||
for (auto i : t.apply_partition(shape(x)))
|
||||
{
|
||||
res(i) = x(i);
|
||||
}
|
||||
};
|
||||
|
||||
return res;
|
||||
}
|
||||
|
||||
int main()
|
||||
{
|
||||
nvtx_range r("run");
|
||||
|
||||
stream_ctx ctx;
|
||||
|
||||
const size_t N = 256 * 1024;
|
||||
const size_t K = 8;
|
||||
|
||||
logical_data<slice<double>> lX[K];
|
||||
logical_data<slice<double>> lY[K];
|
||||
|
||||
for (size_t i = 0; i < K; i++)
|
||||
{
|
||||
lX[i] = ctx.logical_data<double>(N);
|
||||
lY[i] = ctx.logical_data<double>(N);
|
||||
|
||||
ctx.parallel_for(lX[i].shape(), lX[i].write(), lY[i].write()).set_symbol("INIT")->*
|
||||
[] __device__(size_t i, auto x, auto y) {
|
||||
x(i) = 2.0 * i + 12.0;
|
||||
y(i) = -3.0 * i + 17.0;
|
||||
};
|
||||
}
|
||||
|
||||
for (size_t i = 0; i < K; i++)
|
||||
{
|
||||
auto tmp = libCOPY(ctx, lX[i]);
|
||||
libSWAP(ctx, tmp, lY[i]);
|
||||
libMATH_AS_GRAPH(ctx, lX[i], lY[i]);
|
||||
libSWAP(ctx, lX[i], lY[i]);
|
||||
}
|
||||
|
||||
ctx.finalize();
|
||||
}
|
||||
Reference in New Issue
Block a user